import os
import queue
import threading
from .utils import run_command


def quick_push(*args, **kwargs):
    # signal.signal(signal.SIGINT, signal_handler, pid_queue)
    # parameters_dict = get_hyperparameters()
    current_directory = os.getcwd()
    print("Current Directory:", current_directory)
    StarRail = current_directory

    pid_queue = queue.Queue()
    summary = kwargs.get('summary', 'update')
    commands = [
        (StarRail, "git add ."),
        (StarRail, f'git commit -m "{summary}"'),
        (StarRail, "git push"),
    ]
    try:
        print("Running... Press Ctrl+C to interrupt")
        threads = []

        for i, (directory, command) in enumerate(commands):
            thread = threading.Thread(target=run_command, args=(directory, command, pid_queue))
            threads.append(thread)
            thread.start()
            thread.join()

            print("Command completed. Clearing environment before starting the next command...")
            # clear_environment()

    except SystemExit:
        print("Process terminated gracefully")


import argparse
import os
import queue
import signal
import subprocess
import sys
import threading

def enqueue_output(out, q):
    try:
        for line in iter(out.readline, ''):
            q.put(line)
        out.close()
    except Exception as e:
        print(f"Error reading output: {str(e)}")
def run_command(directory, command, pid_queue):
    try:
        # 切换到指定目录
        os.chdir(directory)
        print(f"Running '{command}' in {directory}")
        process = subprocess.Popen(command, shell=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE, text=True,
                                   encoding='utf-8', errors='replace')
        print(process.pid)
        pid_queue.put(process.pid)

        q_stdout = queue.Queue()
        q_stderr = queue.Queue()

        t_stdout = threading.Thread(target=enqueue_output, args=(process.stdout, q_stdout))
        t_stderr = threading.Thread(target=enqueue_output, args=(process.stderr, q_stderr))

        t_stdout.start()
        t_stderr.start()
        print('start')

        while t_stdout.is_alive() or t_stderr.is_alive() or not q_stdout.empty() or not q_stderr.empty():
            while not q_stdout.empty():
                line = q_stdout.get_nowait()
                print(f"{directory}: {line}", end="")
            while not q_stderr.empty():
                line = q_stderr.get_nowait()
                print(f"{directory} [ERROR]: {line}", end="")
        t_stdout.join()
        t_stderr.join()

        return_code = process.wait()
        if return_code:
            raise subprocess.CalledProcessError(return_code, command)
    except subprocess.CalledProcessError as e:
        print(f"An error occurred while running '{command}' in {directory}: {e}")
    except Exception as e:
        print(f"An unexpected error occurred while running '{command}' in {directory}: {str(e)}")

# def signal_handler(sig, frame):
#     print('You pressed Ctrl+C!')
#     pid = os.getpid()  # 获取当前进程的 PID
#     # print(f"Killing process {pid}")
#     print(pid_queue)
#     # os.kill(pid, signal.SIGTERM)
#     while not pid_queue.empty():
#         id = pid_queue.get()
#         try:
#             os.kill(id, signal.SIGTERM)
#             print(f"Killing process {id}")
#         except OSError:
#             print(f"Process {id} already terminated")
#     sys.exit(0)


#!/usr/bin/env python
# PYTHON_ARGCOMPLETE_OK

import argparse
from git_help import quick_pull, quick_push, run_cmd
from git_help import api

# import argcomplete
# from argcomplete.completers import ChoicesCompleter
valid_commands = ['pull', 'push', 'status', 'commit']


def get_hyperparameters():
    parser = argparse.ArgumentParser(description="Set hyperparameters for start server.")
    parser.add_argument("command", type=str,
                        help="Select pull, push or any other command for git")  # .completer = ChoicesCompleter(
    #    valid_commands)
    parser.add_argument("args", nargs='*', help="Positional arguments")
    parser.add_argument("--kwargs", nargs='*', help="Keyword arguments in the form key=value")
    # parser.add_argument("--h", action="store_true",
    #                     help="Print hyperparameter options.")
    # argcomplete.autocomplete(parser)
    args = parser.parse_args()

    kwargs_dict = {}
    if args.kwargs:
        for kwarg in args.kwargs:
            key, value = kwarg.split('=')
            kwargs_dict[key] = value

    # if args.h:
    #     print("Usage: setup_paths.py [command]\n")
    #     print("Positional arguments:")
    #     print("  command    Set the command: 'pull' or 'push'")
    #     exit()
    print(args.command, args.args, kwargs_dict)
    return args.command, args.args, kwargs_dict


def has_function(module, func_name):
    return hasattr(module, func_name) and callable(getattr(module, func_name))


def main():
    command, args, kwargs_dict = get_hyperparameters()
    if command == 'pull':
        quick_pull(*args, **kwargs_dict)
    elif command == 'push':
        quick_push(*args, **kwargs_dict)
    elif has_function(api, command):
        getattr(api, command)(*args, **kwargs_dict)
    else:
        run_cmd(command, *args, **kwargs_dict)


if __name__ == '__main__':
    main()




import os
import queue
import threading
from .utils import run_command


def quick_pull(*args, **kwargs):
    # signal.signal(signal.SIGINT, signal_handler)
    # parameters_dict = get_hyperparameters()
    current_directory = os.getcwd()
    print("Current Directory:", current_directory)

    parent_directory = os.path.dirname(current_directory)
    print("Parent Directory:", parent_directory)

    # 定义三个目录的路径
    star_rail_node = os.path.join(parent_directory, 'star-rail-node')
    star_rail_solid = os.path.join(parent_directory, 'star-rail-solid')
    StarRail = current_directory
    print("Directories:", star_rail_node, star_rail_solid, StarRail)
    pid_queue = queue.Queue()
    commands = [
        (StarRail, "git pull origin api"),
        (star_rail_node, "git pull origin main"),
        (star_rail_solid, "git pull origin main"),
    ]
    try:
        print("Running... Press Ctrl+C to interrupt")
        threads = []

        for i, (directory, command) in enumerate(commands):
            thread = threading.Thread(target=run_command, args=(directory, command, pid_queue))
            threads.append(thread)
            thread.start()
            thread.join()

            print("Command completed. Clearing environment before starting the next command...")
            # clear_environment()

    except SystemExit:
        print("Process terminated gracefully")
